==> openGion6.7.6.0_dev.zip: uap/webapps/gf/src/org/opengion/plugin/table/TableFilter_TABLE_POSTGRES.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.table;

/**
 * TableFilter_TABLE_POSTGRES は、TableUpda インターフェースを継承した、DBTableModel 処理用の
 * 実装クラスです。とくに、PostgreSQL用のDB定義スクリプトを作成します。
 *
 * ここでは、テーブル一覧の検索結果より、GF05 のテーブルカラム定義テーブルから
 * 必要な情報を取得し、テーブル作成スクリプトを作成します。
 * 出力ファイルは、テーブル名＋"S.sql" という命名規則で作成します。
 * 検索では、(SYSTEM_ID,TBLSYU,TABLE_NAME,NAME_JA,TABLESPACE_NAME,INITIAL_EXTENT,COMMENTS)
 * の項目を取得する必要があります。
 *
 * @og.rev 4.0.0.0 (2005/08/31) 新規作成
 * @og.rev 6.5.0.0 (2016/09/30) クラス名変更(TableFilter_TABLE_POSGRE → TableFilter_TABLE_POSTGRES)
 *
 * @version  6.5.0  2000/10/17
 * @author   Kazuhiko Hasegawa
 * @since    JDK1.8,
 */
public class TableFilter_TABLE_POSTGRES extends TableFilter_TABLE {
	/** このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "6.5.0.0 (2016/09/30)" ;

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.2.0 (2016/01/29) PMD refactoring. Each class should declare at least one constructor.
	 * @og.rev 6.5.0.0 (2016/09/30) クラス名変更(TableFilter_TABLE_POSGRE → TableFilter_TABLE_POSTGRES)
	 */
	public TableFilter_TABLE_POSTGRES() {
		super();		// これも、自動的に呼ばれるが、空のメソッドを作成すると警告されるので、明示的にしておきます。
	}

	/**
	 * 各行部分(カラム定義)の処理を実行します。
	 *
	 * @og.rev 5.1.1.0 (2009/12/01) 各カラムの説明を追加
	 * @og.rev 5.3.9.0 (2011/09/01) PRIMARY KEY の作成は、INDEX側で行うこととする。
	 * @og.rev 5.6.9.2 (2013/10/18) useLen が、nullやゼロ文字列の場合の考慮
	 * @og.rev 5.7.2.0 (2014/01/10) useLen が小数の場合の処理が間違っていた。
	 *
	 * @param	data	１行分のデータ配列
	 * @param	first	最初の行かどうか[true:最初/false:それ以降]
	 *
	 * @return	各行部分(カラム定義)配列
	 */
	@Override
	protected String[] makeLineList( final String[] data,final boolean first ) {

		final String clsName = data[GF05_CLS_NAME] ;

		// 5.1.1.0 (2009/12/01) 各カラムの説明文を 入れたくない場合は、null を設定する。
		if( isXml ) { data[GF05_NAME_JA] = null; }

		if( "UNIQ".equalsIgnoreCase( data[GF05_CLM] ) || "UNIQSEQ".equalsIgnoreCase( data[GF05_CLM] ) ) {
			data[GF05_CLS_NAME]     = "SERIAL";
			data[GF05_DATA_DEFAULT] = null;
			data[GF05_NOT_NULL]     = null;
			data[GF05_USE_LENGTH]   = null;
		}
		else if( clsName == null || clsName.isEmpty() || clsName.startsWith( "VARCHAR" ) ) {		// 6.1.0.0 (2014/12/26) refactoring
			data[GF05_CLS_NAME] = "VARCHAR" ;
		}
		else if( clsName.startsWith( "CLOB" ) ) {
			data[GF05_CLS_NAME]     = "TEXT";
			data[GF05_DATA_DEFAULT] = null;
			data[GF05_NOT_NULL]     = null;
			data[GF05_USE_LENGTH]   = null;
		}
		else if( clsName.startsWith( "NUMBER" ) ) {
			final String useLen = data[GF05_USE_LENGTH] ;			// 5.7.2.0 (2014/01/10) 値を退避

			// 5.6.9.2 (2013/10/18) 初期値をあらかじめ設定しておきます。
			data[GF05_CLS_NAME] = "INTEGER";
			data[GF05_USE_LENGTH] = null;

			// 5.6.9.2 (2013/10/18) useLen が、nullやゼロ文字列の場合の考慮
			if( useLen != null && useLen.length() > 0 ) {
				if( useLen.contains( "," ) || useLen.contains( "." ) ) {	// 5.7.2.0 (2014/01/10) カンマとコロンの両方調べる
					data[GF05_CLS_NAME] = "NUMERIC";
				}
				else if( Integer.parseInt( useLen ) >= 10 ) {	// １０桁以上
					data[GF05_CLS_NAME] = "BIGINT";
				}
			}
		}

		return super.makeLineList( data,first );
	}

	/**
	 * 定義の最後の部分の処理を実行します。
	 *
	 * @og.rev 6.0.2.3 (2014/10/10) isXml で、CR + EXEC_END_TAG のキャッシュを作成します。
	 *
	 * @param	clmNo	カラム番号配列
	 * @param	data	１行分のデータ配列
	 *
	 * @return	定義の最後の部分
	 * @og.rtnNotNull
	 */
	@Override
	protected String makeEndLine( final int[] clmNo,final String[] data ) {
		return ")" + execEndTag ;						// 6.0.2.3 (2014/10/10) 改行を含める。
	}

	/**
	 * ユニークシーケンスの作成処理を実行します。
	 *
	 * @param	clmNo	カラム番号配列
	 * @param	data	１行分のデータ配列
	 *
	 * @return	ユニークシーケンス
	 * @og.rtnNotNull
	 */
	@Override
	protected String makeUniqSeq( final int[] clmNo,final String[] data ) {
		return "";
	}

	/**
	 * ユニークシーケンスと関連付けるトリガの作成処理を実行します。
	 *
	 * @param	clmNo		カラム番号配列
	 * @param	data		１行分のデータ配列
	 * @param   uniqName	ユニークトリガ名
	 *
	 * @return	ユニークシーケンスと関連付けるトリガ
	 * @og.rtnNotNull
	 */
	@Override
	protected String makeUniqTrig( final int[] clmNo,final String[] data, final String uniqName ) {
		return "";
	}
}

==> openGion7.2.9.5_dev.zip: uap/webapps/gf/src/org/opengion/plugin/table/TableFilter_TABLE_POSTGRES.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.table;

import java.util.Locale;											// 7.2.9.4 (2020/11/20)

/**
 * TableFilter_TABLE_POSTGRES は、TableUpda インターフェースを継承した、DBTableModel 処理用の
 * 実装クラスです。とくに、PostgreSQL用のDB定義スクリプトを作成します。
 *
 * ここでは、テーブル一覧の検索結果より、GF05 のテーブルカラム定義テーブルから
 * 必要な情報を取得し、テーブル作成スクリプトを作成します。
 * 出力ファイルは、テーブル名＋"S.sql" という命名規則で作成します。
 * 検索では、(SYSTEM_ID,TBLSYU,TABLE_NAME,NAME_JA,TABLESPACE_NAME,INITIAL_EXTENT,COMMENTS)
 * の項目を取得する必要があります。
 *
 * @og.rev 4.0.0.0 (2005/08/31) 新規作成
 * @og.rev 6.5.0.0 (2016/09/30) クラス名変更(TableFilter_TABLE_POSGRE → TableFilter_TABLE_POSTGRES)
 *
 * @version  6.5.0  2000/10/17
 * @author   Kazuhiko Hasegawa
 * @since    JDK1.8,
 */
public class TableFilter_TABLE_POSTGRES extends TableFilter_TABLE {
	/** このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "7.2.9.4 (2020/11/20)" ;

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.2.0 (2016/01/29) PMD refactoring. Each class should declare at least one constructor.
	 * @og.rev 6.5.0.0 (2016/09/30) クラス名変更(TableFilter_TABLE_POSGRE → TableFilter_TABLE_POSTGRES)
	 */
	public TableFilter_TABLE_POSTGRES() { super(); }		// これも、自動的に呼ばれるが、空のメソッドを作成すると警告されるので、明示的にしておきます。

	/**
	 * ヘッダー部分の処理を実行します。
	 *
	 * @og.rev 5.10.25.0 (2020/10/02) 先頭にencodingを付加するために作成
	 *
	 * @param	clmNo	カラム番号配列
	 * @param	data	１行分のデータ配列
	 *
	 * @return	ヘッダー部分の文字列
	 */
	@Override
	protected String makeHeadLine( final int[] clmNo,final String[] data ) {
		String str = isXml ? "" : "\\encoding UTF8;" + CR;
		str += super.makeHeadLine( clmNo,data );
		return str;
	}

	/**
	 * 各行部分(カラム定義)の処理を実行します。
	 *
	 * @og.rev 5.1.1.0 (2009/12/01) 各カラムの説明を追加
	 * @og.rev 5.3.9.0 (2011/09/01) PRIMARY KEY の作成は、INDEX側で行うこととする。
	 * @og.rev 5.6.9.2 (2013/10/18) useLen が、nullやゼロ文字列の場合の考慮
	 * @og.rev 5.7.2.0 (2014/01/10) useLen が小数の場合の処理が間違っていた。
	 * @og.rev 7.2.9.4 (2020/11/20) spotbugs:呼び出したメソッドの Locale パラメータの使用を検討する
	 *
	 * @param	data	１行分のデータ配列
	 * @param	first	最初の行かどうか[true:最初/false:それ以降]
	 *
	 * @return	各行部分(カラム定義)配列
	 */
	@Override
	protected String[] makeLineList( final String[] data,final boolean first ) {

		final String clsName = data[GF05_CLS_NAME] ;

		// 5.1.1.0 (2009/12/01) 各カラムの説明文を 入れたくない場合は、null を設定する。
		if( isXml ) { data[GF05_NAME_JA] = null; }

		if( "UNIQ".equalsIgnoreCase( data[GF05_CLM] ) || "UNIQSEQ".equalsIgnoreCase( data[GF05_CLM] ) ) {
			data[GF05_CLS_NAME]     = "SERIAL";
			data[GF05_DATA_DEFAULT] = null;
			data[GF05_NOT_NULL]     = null;
			data[GF05_USE_LENGTH]   = null;
		}
		else if( clsName == null || clsName.isEmpty() || clsName.startsWith( "VARCHAR" ) ) {		// 6.1.0.0 (2014/12/26) refactoring
			data[GF05_CLS_NAME] = "VARCHAR" ;
		}
		else if( clsName.startsWith( "CLOB" ) ) {
			data[GF05_CLS_NAME]     = "TEXT";
			data[GF05_DATA_DEFAULT] = null;
			data[GF05_NOT_NULL]     = null;
			data[GF05_USE_LENGTH]   = null;
		}
		else if( clsName.startsWith( "NUMBER" ) ) {
			final String useLen = data[GF05_USE_LENGTH] ;			// 5.7.2.0 (2014/01/10) 値を退避

			// 5.6.9.2 (2013/10/18) 初期値をあらかじめ設定しておきます。
			data[GF05_CLS_NAME] = "INTEGER";
			data[GF05_USE_LENGTH] = null;

			// 5.6.9.2 (2013/10/18) useLen が、nullやゼロ文字列の場合の考慮
			if( useLen != null && useLen.length() > 0 ) {
				if( useLen.contains( "," ) || useLen.contains( "." ) ) {	// 5.7.2.0 (2014/01/10) カンマとコロンの両方調べる
//					data[GF05_CLS_NAME] = "NUMERIC";
					data[GF05_CLS_NAME] = clsName.replace( "NUMBER", "NUMERIC" ); // 5.10.25.0 (2020/10/02) 精度情報を残すため、文字列置換に変更
				}
				else if( Integer.parseInt( useLen ) >= 10 ) {	// １０桁以上
					data[GF05_CLS_NAME] = "BIGINT";
				}
			}
		}

		// 5.10.25.0 (2020/10/02) postgresは原則小文字なので変換してしまう
		final String[] rtn =  super.makeLineList( data,first );
		for (int i = 0; i < rtn.length; i++){
//			if( rtn[i] != null ) { rtn[i] = rtn[i].toLowerCase(); }		// 7.3.0.0 (2021/01/06)
			if( rtn[i] != null ) { rtn[i] = rtn[i].toLowerCase(Locale.JAPAN); }		// 7.2.9.4 (2020/11/20)
		}
		return rtn;
//		return super.makeLineList( data,first );
	}

	/**
	 * 定義の最後の部分の処理を実行します。
	 *
	 * @og.rev 6.0.2.3 (2014/10/10) isXml で、CR + EXEC_END_TAG のキャッシュを作成します。
	 *
	 * @param	clmNo	カラム番号配列
	 * @param	data	１行分のデータ配列
	 *
	 * @return	定義の最後の部分
	 * @og.rtnNotNull
	 */
	@Override
	protected String makeEndLine( final int[] clmNo,final String[] data ) {
		return ")" + execEndTag ;						// 6.0.2.3 (2014/10/10) 改行を含める。
	}

	/**
	 * ユニークシーケンスの作成処理を実行します。
	 *
	 * @param	clmNo	カラム番号配列
	 * @param	data	１行分のデータ配列
	 *
	 * @return	ユニークシーケンス
	 * @og.rtnNotNull
	 */
	@Override
	protected String makeUniqSeq( final int[] clmNo,final String[] data ) {
		return "";
	}

	/**
	 * ユニークシーケンスと関連付けるトリガの作成処理を実行します。
	 *
	 * @param	clmNo		カラム番号配列
	 * @param	data		１行分のデータ配列
	 * @param   uniqName	ユニークトリガ名
	 *
	 * @return	ユニークシーケンスと関連付けるトリガ
	 * @og.rtnNotNull
	 */
	@Override
	protected String makeUniqTrig( final int[] clmNo,final String[] data, final String uniqName ) {
		return "";
	}
}
